Sheet

Struct Sheet 

pub struct Sheet {
    pub name: Option<String>,
    pub residue: Option<Residue>,
    pub lattice: LatticeType,
    pub std_z: Option<f64>,
    pub origin: Coord,
    pub normal: Direction,
    pub length: f64,
    pub width: f64,
    pub coords: Vec<Coord>,
}
A rectangular sheet.

Fields

name: Option<String>

Name of component.

residue: Option<Residue>

Optional residue placed at each coordinate. If not set the sheet describes a general collection of coordinates.

lattice: LatticeType

Lattice type used to construct the surface structure.

std_z: Option<f64>

Standard deviation along z of coordinates. Added to the coordinates when construct is called.

origin: Coord

Origin of the sheet. Located in the lower-left position of it.

normal: Direction

Normal vector of the sheet.

length: f64

Length of the sheet along the x axis.

width: f64

Length of the sheet along the y axis.

coords: Vec<Coord>

List of coordinates belonging to the sheet. Relative to the `origin.

Implementations

Source

impl Sheet

pub fn construct(self) -> Result<Sheet>

Construct the sheet coordinates and return the object.

Errors

Returns an error if either the length or width is non-positive.

pub fn to_circle(&self, radius: f64) -> Circle

Cut a circle out of coordinates in the sheet.